@@ -1209,7 +1209,7 @@ Keydata(symset)
 #endif
 	for(;;)
 	{
-		scrname = dir.getName();
+		scrname = (char *)dir.getName();
 		if(!scrname)
 			break;
 		ext = strchr(scrname, '.');
